build_simulation_signed_multi_agent

Function build_simulation_signed_multi_agent 

pub fn build_simulation_signed_multi_agent(
    multi_agent: &MultiAgentRawTransaction,
) -> SignedTransaction
Builds a signed transaction for simulation only (multi-agent).

Uses AccountAuthenticator::NoAccountAuthenticator for all signers so that the transaction can be sent to the simulate endpoint without real signatures. Use this to simulate a multi-agent transaction before collecting signatures.

Example

let multi_agent = MultiAgentRawTransaction::new(raw_txn, secondary_addresses);
let signed = build_simulation_signed_multi_agent(&multi_agent);
let result = aptos.simulate_signed(&signed).await?;